"use strict";
/*---------------------------------------------------------------------------------------------
 * Copyright (c) Bentley Systems, Incorporated. All rights reserved.
 * See LICENSE.md in the project root for license terms and full copyright notice.
 *--------------------------------------------------------------------------------------------*/
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = require("@testing-library/react");
const jest_mock_console_1 = __importDefault(require("jest-mock-console"));
const react_2 = __importDefault(require("react"));
const ErrorBoundary_1 = require("../../containers/ErrorBoundary");
const BrokenComponent_1 = __importStar(require("./BrokenComponent"));
const renderTest = (trigger, additionnalProps) => {
    const { queryByTestId, queryByText } = react_1.render(react_2.default.createElement(ErrorBoundary_1.ErrorBoundary, Object.assign({}, additionnalProps), trigger ? react_2.default.createElement(BrokenComponent_1.default, null) : react_2.default.createElement("div", null, "MOCK_CONTENT")));
    return {
        errorComponent: queryByTestId("test-fallback-text"),
        content: queryByText("MOCK_CONTENT"),
    };
};
describe("ErrorBoundary.tsx Tests", () => {
    test("Should display content and no error message when no error occurs", () => {
        const { errorComponent, content } = renderTest(false);
        expect(errorComponent).toBeNull();
        expect(content).not.toBeNull();
    });
    test("Should display the error message and no content when an error occurs", () => {
        const resetConsole = jest_mock_console_1.default();
        const { errorComponent, content } = renderTest(true);
        expect(errorComponent === null || errorComponent === void 0 ? void 0 : errorComponent.innerHTML).toBe(BrokenComponent_1.ErrorMessage);
        expect(content).toBeNull();
        resetConsole();
    });
    test("Should track event using the provided eventTracker and eventTitle when an error occurs", () => {
        const eventTracker = jest.fn();
        const eventTitle = "MOCK_EVENT";
        const resetConsole = jest_mock_console_1.default();
        renderTest(true, { eventTracker, eventTitle });
        expect(eventTracker).toHaveBeenCalledWith(eventTitle, expect.objectContaining({ error: BrokenComponent_1.ErrorMessage }));
        resetConsole();
    });
});
//# sourceMappingURL=ErrorBoundary.test.js.map